@@ -1,9 +1,11 @@
+#' @describeIn boot Bootstrap a single variable or a grouped variable
+#' @export
+
 boot.formula <-
-function(formula,  data, subset ,  ...)
+function(formula,  data, subset , ...)
 {
 
-    if (missing(formula) || (length(formula) != 3L) || (length(attr(terms(formula[-2L]),
-        "term.labels")) != 1L))
+    if (missing(formula) || (length(formula) > 3L) )
         stop("'formula' missing or incorrect")
 
     m <- match.call(expand.dots = FALSE)
@@ -17,10 +19,19 @@ function(formula,  data, subset ,  ...)
      if (nmiss > 0)
       cat("\n ", nmiss, "observation(s) removed due to missing values.\n")
     varnames <- names(mf)
-    response <- attr(attr(mf, "terms"), "response")
-    y <- mf[[response]]
-    g <- mf[[-response]]
 
-    y <- do.call("boot", c(list(y, g),...))
+      if (length(formula) == 2L){
+    g <- NULL
+    y <- mf[[1]]
+
+    }
+else{
+     response <- attr(attr(mf, "terms"), "response")
+    y <- mf[[response]]
+      g <- mf[[-response]]
+
+     }
+
+       y <- do.call("boot", c(list(y, g,  x.name=varnames[1]), list(...)))
 
 }
